# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpc_gcp.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grpc_gcp.proto',
  package='grpc.gcp',
  syntax='proto3',
  serialized_pb=_b('\n\x0egrpc_gcp.proto\x12\x08grpc.gcp\"g\n\tApiConfig\x12\x31\n\x0c\x63hannel_pool\x18\x02 \x01(\x0b\x32\x1b.grpc.gcp.ChannelPoolConfig\x12\'\n\x06method\x18\xe9\x07 \x03(\x0b\x32\x16.grpc.gcp.MethodConfig\"i\n\x11\x43hannelPoolConfig\x12\x10\n\x08max_size\x18\x01 \x01(\r\x12\x14\n\x0cidle_timeout\x18\x02 \x01(\x04\x12,\n$max_concurrent_streams_low_watermark\x18\x03 \x01(\r\"I\n\x0cMethodConfig\x12\x0c\n\x04name\x18\x01 \x03(\t\x12+\n\x08\x61\x66\x66inity\x18\xe9\x07 \x01(\x0b\x32\x18.grpc.gcp.AffinityConfig\"\x85\x01\n\x0e\x41\x66\x66inityConfig\x12\x31\n\x07\x63ommand\x18\x02 \x01(\x0e\x32 .grpc.gcp.AffinityConfig.Command\x12\x14\n\x0c\x61\x66\x66inity_key\x18\x03 \x01(\t\"*\n\x07\x43ommand\x12\t\n\x05\x42OUND\x10\x00\x12\x08\n\x04\x42IND\x10\x01\x12\n\n\x06UNBIND\x10\x02\x62\x06proto3')
)



_AFFINITYCONFIG_COMMAND = _descriptor.EnumDescriptor(
  name='Command',
  full_name='grpc.gcp.AffinityConfig.Command',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BOUND', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BIND', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNBIND', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=407,
  serialized_end=449,
)
_sym_db.RegisterEnumDescriptor(_AFFINITYCONFIG_COMMAND)


_APICONFIG = _descriptor.Descriptor(
  name='ApiConfig',
  full_name='grpc.gcp.ApiConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_pool', full_name='grpc.gcp.ApiConfig.channel_pool', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='grpc.gcp.ApiConfig.method', index=1,
      number=1001, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28,
  serialized_end=131,
)


_CHANNELPOOLCONFIG = _descriptor.Descriptor(
  name='ChannelPoolConfig',
  full_name='grpc.gcp.ChannelPoolConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_size', full_name='grpc.gcp.ChannelPoolConfig.max_size', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='idle_timeout', full_name='grpc.gcp.ChannelPoolConfig.idle_timeout', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_concurrent_streams_low_watermark', full_name='grpc.gcp.ChannelPoolConfig.max_concurrent_streams_low_watermark', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=238,
)


_METHODCONFIG = _descriptor.Descriptor(
  name='MethodConfig',
  full_name='grpc.gcp.MethodConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grpc.gcp.MethodConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='affinity', full_name='grpc.gcp.MethodConfig.affinity', index=1,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=313,
)


_AFFINITYCONFIG = _descriptor.Descriptor(
  name='AffinityConfig',
  full_name='grpc.gcp.AffinityConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='grpc.gcp.AffinityConfig.command', index=0,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='affinity_key', full_name='grpc.gcp.AffinityConfig.affinity_key', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AFFINITYCONFIG_COMMAND,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=316,
  serialized_end=449,
)

_APICONFIG.fields_by_name['channel_pool'].message_type = _CHANNELPOOLCONFIG
_APICONFIG.fields_by_name['method'].message_type = _METHODCONFIG
_METHODCONFIG.fields_by_name['affinity'].message_type = _AFFINITYCONFIG
_AFFINITYCONFIG.fields_by_name['command'].enum_type = _AFFINITYCONFIG_COMMAND
_AFFINITYCONFIG_COMMAND.containing_type = _AFFINITYCONFIG
DESCRIPTOR.message_types_by_name['ApiConfig'] = _APICONFIG
DESCRIPTOR.message_types_by_name['ChannelPoolConfig'] = _CHANNELPOOLCONFIG
DESCRIPTOR.message_types_by_name['MethodConfig'] = _METHODCONFIG
DESCRIPTOR.message_types_by_name['AffinityConfig'] = _AFFINITYCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ApiConfig = _reflection.GeneratedProtocolMessageType('ApiConfig', (_message.Message,), dict(
  DESCRIPTOR = _APICONFIG,
  __module__ = 'grpc_gcp_pb2'
  # @@protoc_insertion_point(class_scope:grpc.gcp.ApiConfig)
  ))
_sym_db.RegisterMessage(ApiConfig)

ChannelPoolConfig = _reflection.GeneratedProtocolMessageType('ChannelPoolConfig', (_message.Message,), dict(
  DESCRIPTOR = _CHANNELPOOLCONFIG,
  __module__ = 'grpc_gcp_pb2'
  # @@protoc_insertion_point(class_scope:grpc.gcp.ChannelPoolConfig)
  ))
_sym_db.RegisterMessage(ChannelPoolConfig)

MethodConfig = _reflection.GeneratedProtocolMessageType('MethodConfig', (_message.Message,), dict(
  DESCRIPTOR = _METHODCONFIG,
  __module__ = 'grpc_gcp_pb2'
  # @@protoc_insertion_point(class_scope:grpc.gcp.MethodConfig)
  ))
_sym_db.RegisterMessage(MethodConfig)

AffinityConfig = _reflection.GeneratedProtocolMessageType('AffinityConfig', (_message.Message,), dict(
  DESCRIPTOR = _AFFINITYCONFIG,
  __module__ = 'grpc_gcp_pb2'
  # @@protoc_insertion_point(class_scope:grpc.gcp.AffinityConfig)
  ))
_sym_db.RegisterMessage(AffinityConfig)


# @@protoc_insertion_point(module_scope)
